============
**metameta**
============

*Purpose*
---------
Toolkit for analyzing meta-transcriptome/metagenome mapping data

*Requirements*
--------------
- Python 3.4 or higher
- pysam 0.8.2.1 or higher

*Installation*
--------------
''pip install metameta''

*Usage*
-------
metameta <tool name> [arguments for tool]


